==> zio-aws-ec2_2.12-6.20.78.1-sources.jar: zio/aws/ec2/model/DeleteCustomerGatewayRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.CustomerGatewayId
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteCustomerGatewayRequest(
    customerGatewayId: CustomerGatewayId
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DeleteCustomerGatewayRequest = {
    import DeleteCustomerGatewayRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DeleteCustomerGatewayRequest
      .builder()
      .customerGatewayId(
        CustomerGatewayId.unwrap(customerGatewayId): java.lang.String
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DeleteCustomerGatewayRequest.ReadOnly =
    zio.aws.ec2.model.DeleteCustomerGatewayRequest.wrap(buildAwsValue())
}
object DeleteCustomerGatewayRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DeleteCustomerGatewayRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DeleteCustomerGatewayRequest =
      zio.aws.ec2.model.DeleteCustomerGatewayRequest(customerGatewayId)
    def customerGatewayId: CustomerGatewayId
    def getCustomerGatewayId: ZIO[Any, Nothing, CustomerGatewayId] =
      ZIO.succeed(customerGatewayId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DeleteCustomerGatewayRequest
  ) extends zio.aws.ec2.model.DeleteCustomerGatewayRequest.ReadOnly {
    override val customerGatewayId: CustomerGatewayId =
      zio.aws.ec2.model.primitives.CustomerGatewayId(impl.customerGatewayId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DeleteCustomerGatewayRequest
  ): zio.aws.ec2.model.DeleteCustomerGatewayRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.12-7.21.15.7-sources.jar: zio/aws/ec2/model/DeleteCustomerGatewayRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.CustomerGatewayId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeleteCustomerGatewayRequest(
    customerGatewayId: CustomerGatewayId,
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DeleteCustomerGatewayRequest = {
    import DeleteCustomerGatewayRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DeleteCustomerGatewayRequest
      .builder()
      .customerGatewayId(
        CustomerGatewayId.unwrap(customerGatewayId): java.lang.String
      )
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DeleteCustomerGatewayRequest.ReadOnly =
    zio.aws.ec2.model.DeleteCustomerGatewayRequest.wrap(buildAwsValue())
}
object DeleteCustomerGatewayRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DeleteCustomerGatewayRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DeleteCustomerGatewayRequest =
      zio.aws.ec2.model.DeleteCustomerGatewayRequest(
        customerGatewayId,
        dryRun.map(value => value)
      )
    def customerGatewayId: CustomerGatewayId
    def dryRun: Optional[Boolean]
    def getCustomerGatewayId: ZIO[Any, Nothing, CustomerGatewayId] =
      ZIO.succeed(customerGatewayId)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DeleteCustomerGatewayRequest
  ) extends zio.aws.ec2.model.DeleteCustomerGatewayRequest.ReadOnly {
    override val customerGatewayId: CustomerGatewayId =
      zio.aws.ec2.model.primitives.CustomerGatewayId(impl.customerGatewayId())
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DeleteCustomerGatewayRequest
  ): zio.aws.ec2.model.DeleteCustomerGatewayRequest.ReadOnly = new Wrapper(impl)
}
